**********************
No Reference Metrics
**********************

No reference metrics are calculated on one image only. No reference image is needed.

.. toctree::
    :maxdepth: 1

    nr_metrics/snr
    nr_metrics/cnr
    nr_metrics/qmeasure